import React, { useMemo } from 'react';
import * as echarts from 'echarts/core';
import deepCopy from '@/utils/deepCopy';
import { hex2Rgb } from '@/utils/color';
import { colorArr } from '@/components/ScreenBox/utils';
import BasicChart from './BasicChart';

const colorList = colorArr.map((x) => {
  const rgb = hex2Rgb(x);
  return new echarts.graphic.LinearGradient(0, 1, 1, 1, [
    {
      offset: 0,
      color: `rgba(${rgb[0]}, ${rgb[1]}, ${rgb[2]}, 0)`, // 0% 处的颜色
    },
    {
      offset: 0.8,
      color: x, // 80% 处的颜色
    },
    {
      offset: 1,
      color: x, // 100% 处的颜色
    },
  ]);
});

const defaultOpt = {
  tooltip: {
    extraCssText: 'width:160px;height:40px;',
  },
  legend: {},
  grid: {
    top: 20,
    right: 40,
    bottom: 20,
    left: 10,
    containLabel: true,
  },
  xAxis: {
    type: 'value',
    splitLine: {
      show: false,
    },
    axisTick: {
      show: false,
    },
    axisLabel: {
      show: false,
    },
  },
  yAxis: {
    type: 'category',
    axisLine: {
      show: false,
    },
    axisTick: {
      show: false,
    },
    axisLabel: {
      color: '#fff',
      width: 40,
      overflow: 'truncate',
    },
  },
  series: [
    {
      type: 'bar',
      barMaxWidth: 16,
      itemStyle: {
        borderRadius: 10,
      },
      encode: {
        x: 'value',
        y: 'key',
      },
      label: {
        show: true,
        color: '#fff',
        textBorderWidth: 0,
        position: 'right',
        // align: 'right',
      },
      // showBackground: true,
    },
  ],
};

export default (props) => {
  const option = useMemo(() => deepCopy(defaultOpt), []);
  option.yAxis.data = props.source.map((x) => x.name);
  option.series[0].data = props.source.map((x, i) => ({
    value: x.value,
    itemStyle: {
      color: colorList[i % 3],
    },
  }));

  return <BasicChart title="农机类型统计" option={option} />;
};
